@@ -1,4 +1,4 @@
-/* Stereograph 0.15, 10/04/2000;
+/* Stereograph 0.16, 12/04/2000;
  * Graphics I/O functions;
  * Copyright (c) 2000 by Fabian Januszewski <fabian.linux@januszewski.de>
  *
@@ -23,7 +23,7 @@
 
 #include "renderer.h"
 #include "gfxio.h"
-
+#include "globals.h"
 
 int Read_Gfx_File (char *file_name, struct GFX_DATA *gfx)
 {
@@ -33,7 +33,8 @@ int Read_Gfx_File (char *file_name, struct GFX_DATA *gfx)
 	ifile = fopen(file_name, "r");
 
 	if(ifile == NULL) {
-		printf("FAILED;\ncannot open file '%s'!\n", file_name);
+		if(verbose) printf("FAILED;\n"); else fprintf(stderr, "loading gfx data...FAILED;\n");
+		fprintf(stderr, "cannot open file '%s'!\n", file_name);
 		return -1;
 	} else {
 		a = Read_TARGA(ifile, gfx);
@@ -44,6 +45,30 @@ int Read_Gfx_File (char *file_name, struct GFX_DATA *gfx)
 }
 
 
+int Write_Gfx_File (char *file_name, struct GFX_DATA *gfx)
+{
+	int a;
+	FILE *ofile = NULL;
+
+	if(verbose) printf("saving '%s' (%i*%i)...", file_name, gfx->Width, gfx->Height);
+	if(!file_name)
+		return Write_PIPE(stdout, gfx);
+	else {
+		ofile = fopen(file_name, "w+");
+
+		if(ofile == NULL) {
+			if(verbose) printf("FAILED;\n"); else fprintf(stderr, "writing gfx data...FAILED;\n");
+			fprintf(stderr, "cannot create file %s!\n", file_name);
+			return -1;
+		} else
+			a = Write_TARGA(ofile, gfx);
+		fclose(ofile);
+		ofile = NULL;
+		return a;
+	}
+}
+
+
 int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx)
 {
 	/* TARGA uses the Intel format for integer coding (low byte first) */
@@ -53,7 +78,8 @@ int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx)
 
 	/* reading all header information */
 	if(fread(header, sizeof(char), 18, ifile) != 18) {
-		printf("FAILED!\ncannot read file.\n");
+		if(verbose) printf("FAILED!\n"); else fprintf(stderr, "reading gfx data...FAILED;\n");
+		fprintf(stderr, "cannot read header! (file corrupt?)\n");
 		return -2;
 	}
 
@@ -62,10 +88,11 @@ int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx)
 	gfx->Height = (int)header[14] + (int)header[15]*256;
 	gfx->Data = (int*)malloc(gfx->Width*gfx->Height*sizeof(int));
 	if(!gfx->Data) {
-		printf("FAILED;\nerror allocating memory for image dimensions of %i * %i pixels in 32 bit\n", gfx->Width, gfx->Height);
-		printf("debug - header follows:\n");
+		if(verbose) printf("FAILED;\n"); else fprintf(stderr, "reading gfx data...FAILED;\n");
+		fprintf(stderr, "error allocating memory for image dimensions of %i * %i pixels in 32 bit\n", gfx->Width, gfx->Height);
+		fprintf(stderr, "debug - header follows:\n");
 		for(x = 0; x < 20; x += 4)
-			printf(" %i, %i, %i, %i;\n", (int)header[x], (int)header[x + 1], (int)header[x + 2], (int)header[x + 3]);
+			fprintf(stderr, " %i, %i, %i, %i;\n", (int)header[x], (int)header[x + 1], (int)header[x + 2], (int)header[x + 3]);
 		return -3;
 	}
 
@@ -102,7 +129,7 @@ int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx)
 						Read_TARGA_RGB(ifile, (int)header[16], palette, gfx->Data + (y * gfx->Width) + x);
 			}
 		}
-		printf("gfx data read (%i*%i);\n", gfx->Width, gfx->Height);
+		if(verbose) printf("gfx data read (%i*%i);\n", gfx->Width, gfx->Height);
 		free(palette);
 		return 0;
 	} else if(((header[2] == 10) && (header[16] >= 16)) || (((header[2] == 9) || header[2] == 11) && (header[16] == 8))) {
@@ -121,7 +148,7 @@ int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx)
 					if((x < gfx->Width) && (y < gfx->Height) && (x >= 0) && (y >= 0))
 						gfx->Data[(y * gfx->Width) + x] = c;
 					else
-						printf("(%i, %i) => error\n", x, y);
+						fprintf(stderr, "(%i, %i) => error\n", x, y);
 					z++;
 				}
 			} else { /* uncompressed data follows */
@@ -135,16 +162,17 @@ int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx)
 					if((x < gfx->Width) && (y < gfx->Height) && (x >= 0) && (y >= 0))
 						Read_TARGA_RGB(ifile, (int)header[16], palette, gfx->Data + (y * gfx->Width) + x);
 					else
-						printf("(%i, %i) => error\n", x, y);
+						fprintf(stderr, "(%i, %i) => error\n", x, y);
 					z++;
 				}
 			}
 		}
-		printf("gfx data read (%i*%i);\n", gfx->Width, gfx->Height);
+		if(verbose) printf("gfx data read (%i*%i);\n", gfx->Width, gfx->Height);
 		free(palette);
 		return 0;
 	} else {
-		printf("FAILED;\nUnsupported Targa Data Format %i@%i;\nOnly TARGA types 1, 2, 3 (uncompressed) and 9, 10, 11 (RLE) are supported;\n", header[2], header[16]);
+		if(verbose) printf("FAILED;\n"); else fprintf(stderr, "reading gfx data...FAILED;\n");
+		fprintf(stderr, "Unsupported Targa Data Format %i@%i;\nOnly TARGA types 1, 2, 3 (uncompressed) and 9, 10, 11 (RLE) are supported;\n", header[2], header[16]);
 		free(palette);
 		return -1;
 	}
@@ -178,64 +206,62 @@ int Read_TARGA_RGB(FILE *ifile, int bits, int *palette, int *c) {
 	return a; /* attribute (alpha/transparency information, 32 bit only) */
 }
 
-int Write_TARGA (char *file_name, struct GFX_DATA *gfx)
+/* writes all gfx data to stdout, preceded by the resolution of gfx data - everything 32 bit wide */
+int Write_PIPE (FILE *pp, struct GFX_DATA *gfx)
+{
+	fwrite(&(gfx->Width), sizeof(int), 1, pp);
+	fwrite(&(gfx->Height), sizeof(int), 1, pp);
+	fwrite(gfx->Data, sizeof(int), (gfx->Width) * (gfx->Height), pp);
+	return 0;
+}
+
+int Write_TARGA (FILE *ofile, struct GFX_DATA *gfx)
 {
-	FILE *ofile = NULL;
 	int a, x, y;
-
-	ofile = fopen(file_name, "w+");
-
-	if(ofile == NULL) {
-		printf("FAILED;\ncannot create file %s!\n", file_name);
-		return -1;
-	} else {
-		printf("saving '%s' (%i*%i)...", file_name, gfx->Width, gfx->Height);
-		/* standard TARGA header consists of 18 bytes */
-		/* id tag length */
-		putc(strlen("created by stereograph"), ofile);
-		/* color pallette, yes/no */
-		putc(0, ofile);
-		/* TARGA type 2: RGB 24 bit, no pallette */
-		putc(2, ofile);
-		/* 5 following bytes contain only pallette information */
-		putc(0, ofile);
-		putc(0, ofile);
-		putc(0, ofile);
-		putc(0, ofile);
-		putc(0, ofile);
-		/* x offset */
-		putc(0, ofile);
-		putc(0, ofile);
-		/* y offset */
-		putc(0, ofile);
-		putc(0, ofile);
-		/* width, low byte first */
-		putc(gfx->Width & 255, ofile);
-		putc((gfx->Width >> 8) & 255, ofile);
-		/* height */
-		putc(gfx->Height & 255, ofile);
-		putc((gfx->Height >> 8) & 255, ofile);
-		/* bits per pixel */
-		putc(32-8, ofile);
-		/* Image Descriptor Flags */
-		putc(0, ofile);
-		fwrite("created by stereograph", sizeof(char), strlen("created by stereograph"), ofile);
-		/* data follows */
-		a = 0;
-		for(y = gfx->Height - 1; (y >= 0) && (a != EOF); y--)
-			for(x = 0; (x < gfx->Width) && (a != EOF); x++)	{
-				putc(gfx->Data[y * gfx->Width + x] & 255, ofile);
-				putc((gfx->Data[y * gfx->Width + x] >> 8) & 255, ofile);
-				a = putc((gfx->Data[y * gfx->Width + x] >> 16) & 255, ofile);
-			}
-		fclose(ofile);
-		if(a != EOF) {
-			printf("completed;\n");
-			return 0;
-		} else {
-			printf("FAILED;\n");
-			return -1;
+	/* standard TARGA header consists of 18 bytes */
+	/* id tag length */
+	putc(strlen("created by stereograph"), ofile);
+	/* color pallette, yes/no */
+	putc(0, ofile);
+	/* TARGA type 2: RGB 24 bit, no pallette */
+	putc(2, ofile);
+	/* 5 following bytes contain only pallette information */
+	putc(0, ofile);
+	putc(0, ofile);
+	putc(0, ofile);
+	putc(0, ofile);
+	putc(0, ofile);
+	/* x offset */
+	putc(0, ofile);
+	putc(0, ofile);
+	/* y offset */
+	putc(0, ofile);
+	putc(0, ofile);
+	/* width, low byte first */
+	putc(gfx->Width & 255, ofile);
+	putc((gfx->Width >> 8) & 255, ofile);
+	/* height */
+	putc(gfx->Height & 255, ofile);
+	putc((gfx->Height >> 8) & 255, ofile);
+	/* bits per pixel */
+	putc(32-8, ofile);
+	/* Image Descriptor Flags */
+	putc(0, ofile);
+	fwrite("created by stereograph", sizeof(char), strlen("created by stereograph"), ofile);
+	/* data follows */
+	a = 0;
+	for(y = gfx->Height - 1; (y >= 0) && (a != EOF); y--)
+		for(x = 0; (x < gfx->Width) && (a != EOF); x++)	{
+			putc(gfx->Data[y * gfx->Width + x] & 255, ofile);
+			putc((gfx->Data[y * gfx->Width + x] >> 8) & 255, ofile);
+			a = putc((gfx->Data[y * gfx->Width + x] >> 16) & 255, ofile);
 		}
-
+	if(a != EOF) {
+		if(verbose) printf("completed;\n");
+		return 0;
+	} else {
+		if(verbose) printf("FAILED;\n"); else fprintf(stderr, "writing gfx data...FAILED;\n");
+			fprintf(stderr, "cannot write to file! (disk full?)\n");
+		return -1;
 	}
 }
\ No newline at end of file
