@@ -20,10 +20,12 @@
 
 /* gfx io functions */
 int Read_Gfx_File (char *file_name, struct GFX_DATA *gfx);
-int Write_TARGA (char *file_name, struct GFX_DATA *gfx);
+int Write_Gfx_File (char *file_name, struct GFX_DATA *gfx);
 
 
 /* gfxio internals */
 int Read_TARGA (FILE *ifile, struct GFX_DATA *gfx);
 int Read_TARGA_RGB(FILE *ifile, int bits, int *palette, int *c);
 
+int Write_PIPE (FILE *pp, struct GFX_DATA *gfx);
+int Write_TARGA (FILE *ofile, struct GFX_DATA *gfx);
