@@ -1,4 +1,4 @@
-/* Stereograph 0.15, 10/04/2000;
+/* Stereograph 0.16, 12/04/2000;
  * Copyright (c) 2000 by Fabian Januszewski <fabian.linux@januszewski.de>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 #include "renderer.h"
 #include "gfxio.h"
 #include "stereograph.h"
+#include "globals.h"
 
 
 char *base_file_name;
@@ -35,14 +36,13 @@ struct GFX_DATA *pBase, *pTexture, *pStereo;
 
 
 void print_info(void) {
-	printf("SYNOPSIS\n  stereograph [OPTIONS] -b [FILENAME] -t [FILENAME] -o [FILENAME]\n\n");
-	printf("OPTIONS\n  -a anti-aliasing     -z zoom               (quality)\n  -d distance          -e eye shift          (perspective)\n  -x texture insert x  -y texture insert y   (layout)\n  -r this flag enables anti-artefact feature (experimental)\n\n");
+	printf("SYNOPSIS\n  stereograph [OPTIONS] -b [FILENAME] -t [FILENAME] [-o [FILENAME]]\n\n");
+	printf("OPTIONS\n  -a anti-aliasing     -z zoom               (quality)\n  -d distance          -e eye shift          (perspective)\n  -x texture insert x  -y texture insert y   (layout)\n  -r this flag enables anti-artefact feature (experimental)\n  -v you should know this flag :)\n\n");
 }
 
 int main (int argc, char **argv) {
 
 	int last_error = 0;
-	printf("Stereograph for linux Version %s\n(c) 2000 Fabian Januszewski\n\n", "0.15");
 
 	Get_GFX_Pointers(&pParam, &pBase, &pTexture, &pStereo);
 
@@ -62,47 +62,57 @@ int main (int argc, char **argv) {
 	texture_file_name = NULL;
 	stereo_file_name = NULL;
 
+	verbose = 0;
+
 	parse_args(argc, argv);
 
-	if(base_file_name && texture_file_name && stereo_file_name) {
-		printf("loading base '%s'...", base_file_name);
+	if(verbose) printf("Stereograph for linux Version %s\n", "0.16");
+
+
+
+
+	if(base_file_name && texture_file_name) {
+		if(verbose) printf("loading base '%s'...", base_file_name);
 		if(!Read_Gfx_File(base_file_name, pBase)) {
-			printf("loading texture '%s'...", texture_file_name);
+			if(verbose) printf("loading texture '%s'...", texture_file_name);
 			if(!Read_Gfx_File(texture_file_name, pTexture)) {
 
 				/* setting up renderer; */
-				printf("initializing renderer...");
+				if(verbose) printf("initializing renderer...");
 				if(!(last_error = Initialize_Renderer())) {
 					int y, s;
-					printf("success;\n");
-					printf("using parametres as follows (zadexy): %i %i %f %f %i %i;\n", pParam->Zoom, pParam->AA, pParam->Distance, pParam->Eyeshift, pParam->Startx, pParam->Starty);
-					if(pParam->AAr)
+					if(verbose) printf("success;\n");
+					if(verbose) printf("using parametres as follows (zadexy): %i %i %f %f %i %i;\n", pParam->Zoom, pParam->AA, pParam->Distance, pParam->Eyeshift, pParam->Startx, pParam->Starty);
+					if(verbose && pParam->AAr)
 						printf("experimental anti-artefacts feature enabled;\n");
-					printf("processing...");
+					if(verbose) printf("processing...");
 
-					for(y = 0, s = 0; y < pBase->Height; y++) {
+					for(y = 0, s = 0; (y < pBase->Height); y++) {
 						ProcessLine(y);
 						/* print simple status points (without refresh) */
-						for( ; s < (58 * y / pBase->Height); s++)
+						for( ; verbose && (s < (58 * y / pBase->Height)); s++)
 							printf(".");
 					}
 
-					printf("completed;\n");
+					if(verbose) printf("completed;\n");
 	
-					printf("writing stereogram to disk...");
-					Write_TARGA(stereo_file_name, pStereo);
+					if(verbose) printf("writing stereogram to disk...");
+					Write_Gfx_File(stereo_file_name, pStereo);
 				} else {
-					printf("FAILED;\n");
+					if(verbose)
+						printf("FAILED;\n");
+					else
+						fprintf(stderr, "initializing renderer...FAILED;\n");
 					switch (last_error) {
 						case -1 :
-							printf("illegal parametre;\n\n");
+							fprintf(stderr, "illegal parametre;\n\n");
 							print_info();
 							break;
 						case -2 :
-							printf("width of texture file greater than the base;\nthis state is not processable;\n");
+							fprintf(stderr, "width of texture file greater than the base;\nthis state is not processable;\n");
 							break;
 						case -3 :
-							printf("could not allocate memory.\n");
+							fprintf(stderr, "could not allocate memory.\n");
 					}
 					return -1;
 				}
@@ -112,7 +122,7 @@ int main (int argc, char **argv) {
 		}
 		free(pBase->Data);
 	} else {
-		printf("NOTIFY: must specify base, texture and output files!\n\n");
+		fprintf(stderr, "NOTIFY: must specify at least a base and a texture file!\n\n");
 		print_info();
 		return -1;
 	}
@@ -139,9 +149,6 @@ int parse_args (int argc, char **argv) {
 				case 'y' :
 					pParam->Starty = atoi(argv[++z]);
 					break;
-				/*case 'f' :
-					pParam->Front = (float) atof(argv[++z]);
-					break;*/
 				case 'd' :
 					pParam->Distance = (float) atof(argv[++z]);
 					break;
@@ -157,7 +164,10 @@ int parse_args (int argc, char **argv) {
 				case 'r' :
 					pParam->AAr = 1;
 					break;
-				printf("invalid argument '%c';\n", argv[z][1]);
+				case 'v' :
+					verbose = 1;
+					break;
+				fprintf(stderr, "invalid argument '%c';\n", argv[z][1]);
 				return -1;
 			}
 	return 0;
